==> jc-1.4.0.tar.gz: soot/jimple/parser/node/ANativeModifier.h <==
// public final class soot.jimple.parser.node.ANativeModifier

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b69c653bd64343c5 soot_jimple_parser_node_ANativeModifier
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 3b296b90432e6f7 soot_jimple_parser_node_PModifier

// header file dependencies
// @dep_header soot_jimple_parser_node_PModifier

#include "soot/jimple/parser/node/PModifier.h"

#ifndef _JC_soot_jimple_parser_node_ANativeModifier_H_
#define _JC_soot_jimple_parser_node_ANativeModifier_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TNative$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_ANativeModifier$sub_refs	_jc_soot_jimple_parser_node_ANativeModifier$sub_refs;
typedef struct _jc_soot_jimple_parser_node_ANativeModifier$sub_nonrefs	_jc_soot_jimple_parser_node_ANativeModifier$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_ANativeModifier$refs	_jc_soot_jimple_parser_node_ANativeModifier$refs;
typedef struct _jc_soot_jimple_parser_node_ANativeModifier$nonrefs	_jc_soot_jimple_parser_node_ANativeModifier$nonrefs;
typedef struct _jc_soot_jimple_parser_node_ANativeModifier$object	_jc_soot_jimple_parser_node_ANativeModifier$object;

typedef const struct _jc_soot_jimple_parser_node_ANativeModifier$vmethods	_jc_soot_jimple_parser_node_ANativeModifier$vmethods;
typedef const struct _jc_soot_jimple_parser_node_ANativeModifier$vtable	_jc_soot_jimple_parser_node_ANativeModifier$vtable;
typedef const struct _jc_soot_jimple_parser_node_ANativeModifier$vtype	_jc_soot_jimple_parser_node_ANativeModifier$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_ANativeModifier$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_ANativeModifier$object *);
extern void _jc_soot_jimple_parser_node_ANativeModifier$method$_init$adce07f1e855a550(_jc_env *, struct _jc_soot_jimple_parser_node_ANativeModifier$object *, struct _jc_soot_jimple_parser_node_TNative$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_ANativeModifier$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_ANativeModifier$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_ANativeModifier$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_ANativeModifier$object *);
extern struct _jc_soot_jimple_parser_node_TNative$object *_jc_soot_jimple_parser_node_ANativeModifier$method$getNative$c3526f2aadfbb028(_jc_env *, struct _jc_soot_jimple_parser_node_ANativeModifier$object *);
extern void _jc_soot_jimple_parser_node_ANativeModifier$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_ANativeModifier$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_ANativeModifier$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_ANativeModifier$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_ANativeModifier$method$setNative$6e41ce3729cc6f79(_jc_env *, struct _jc_soot_jimple_parser_node_ANativeModifier$object *, struct _jc_soot_jimple_parser_node_TNative$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_ANativeModifier$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_ANativeModifier$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_ANativeModifier$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_ANativeModifier$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_ANativeModifier$method_info$getNative$c3526f2aadfbb028;
extern _jc_method _jc_soot_jimple_parser_node_ANativeModifier$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_ANativeModifier$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_ANativeModifier$method_info$setNative$6e41ce3729cc6f79;
extern _jc_method _jc_soot_jimple_parser_node_ANativeModifier$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_ANativeModifier$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_ANativeModifier$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_ANativeModifier$object *);
	struct _jc_soot_jimple_parser_node_TNative$object	*(*getNative$c3526f2aadfbb028)(_jc_env *, struct _jc_soot_jimple_parser_node_ANativeModifier$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_ANativeModifier$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_ANativeModifier$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setNative$6e41ce3729cc6f79)(_jc_env *, struct _jc_soot_jimple_parser_node_ANativeModifier$object *, struct _jc_soot_jimple_parser_node_TNative$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_ANativeModifier$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_ANativeModifier$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PModifier$vmethods	soot_jimple_parser_node_PModifier;
	_jc_soot_jimple_parser_node_ANativeModifier$vmethods	soot_jimple_parser_node_ANativeModifier;
};

// Vtype
struct _jc_soot_jimple_parser_node_ANativeModifier$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_ANativeModifier$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ANativeModifier$sub_refs {
	struct _jc_soot_jimple_parser_node_TNative$object	*__5fnative__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_ANativeModifier$refs {
    _jc_soot_jimple_parser_node_ANativeModifier$sub_refs	soot_jimple_parser_node_ANativeModifier;
    _jc_soot_jimple_parser_node_PModifier$sub_refs	soot_jimple_parser_node_PModifier;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ANativeModifier$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_ANativeModifier$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PModifier$sub_nonrefs	soot_jimple_parser_node_PModifier;
    _jc_soot_jimple_parser_node_ANativeModifier$sub_nonrefs	soot_jimple_parser_node_ANativeModifier;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_ANativeModifier$object {
	_jc_soot_jimple_parser_node_ANativeModifier$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_ANativeModifier$vtype	*vtype;
	_jc_soot_jimple_parser_node_ANativeModifier$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_ANativeModifier$vtype _jc_soot_jimple_parser_node_ANativeModifier$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_ANativeModifier, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_ANativeModifier$class_object;

#endif	/* _JC_soot_jimple_parser_node_ANativeModifier_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/ANativeModifier.h <==
// public final class soot.jimple.parser.node.ANativeModifier

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b69c653bd64343c5 soot_jimple_parser_node_ANativeModifier
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 3b296b90432e6f7 soot_jimple_parser_node_PModifier

// header file dependencies
// @dep_header soot_jimple_parser_node_PModifier

#include "soot/jimple/parser/node/PModifier.h"

#ifndef _JC_soot_jimple_parser_node_ANativeModifier_H_
#define _JC_soot_jimple_parser_node_ANativeModifier_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TNative$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_ANativeModifier$sub_refs	_jc_soot_jimple_parser_node_ANativeModifier$sub_refs;
typedef struct _jc_soot_jimple_parser_node_ANativeModifier$sub_nonrefs	_jc_soot_jimple_parser_node_ANativeModifier$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_ANativeModifier$refs	_jc_soot_jimple_parser_node_ANativeModifier$refs;
typedef struct _jc_soot_jimple_parser_node_ANativeModifier$nonrefs	_jc_soot_jimple_parser_node_ANativeModifier$nonrefs;
typedef struct _jc_soot_jimple_parser_node_ANativeModifier$object	_jc_soot_jimple_parser_node_ANativeModifier$object;

typedef const struct _jc_soot_jimple_parser_node_ANativeModifier$vmethods	_jc_soot_jimple_parser_node_ANativeModifier$vmethods;
typedef const struct _jc_soot_jimple_parser_node_ANativeModifier$vtable	_jc_soot_jimple_parser_node_ANativeModifier$vtable;
typedef const struct _jc_soot_jimple_parser_node_ANativeModifier$vtype	_jc_soot_jimple_parser_node_ANativeModifier$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_ANativeModifier$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_ANativeModifier$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ANativeModifier$method$_init$adce07f1e855a550(_jc_env *, struct _jc_soot_jimple_parser_node_ANativeModifier$object *, struct _jc_soot_jimple_parser_node_TNative$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_ANativeModifier$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_ANativeModifier$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_ANativeModifier$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_ANativeModifier$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_TNative$object *_jc_soot_jimple_parser_node_ANativeModifier$method$getNative$c3526f2aadfbb028(_jc_env *, struct _jc_soot_jimple_parser_node_ANativeModifier$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ANativeModifier$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_ANativeModifier$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ANativeModifier$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_ANativeModifier$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ANativeModifier$method$setNative$6e41ce3729cc6f79(_jc_env *, struct _jc_soot_jimple_parser_node_ANativeModifier$object *, struct _jc_soot_jimple_parser_node_TNative$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_ANativeModifier$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_ANativeModifier$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_ANativeModifier$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_ANativeModifier$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_ANativeModifier$method_info$getNative$c3526f2aadfbb028;
extern _jc_method _jc_soot_jimple_parser_node_ANativeModifier$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_ANativeModifier$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_ANativeModifier$method_info$setNative$6e41ce3729cc6f79;
extern _jc_method _jc_soot_jimple_parser_node_ANativeModifier$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_ANativeModifier$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_ANativeModifier$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_ANativeModifier$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_TNative$object	*(*getNative$c3526f2aadfbb028)(_jc_env *, struct _jc_soot_jimple_parser_node_ANativeModifier$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_ANativeModifier$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_ANativeModifier$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setNative$6e41ce3729cc6f79)(_jc_env *, struct _jc_soot_jimple_parser_node_ANativeModifier$object *, struct _jc_soot_jimple_parser_node_TNative$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_ANativeModifier$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_ANativeModifier$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PModifier$vmethods	soot_jimple_parser_node_PModifier;
	_jc_soot_jimple_parser_node_ANativeModifier$vmethods	soot_jimple_parser_node_ANativeModifier;
};

// Vtype
struct _jc_soot_jimple_parser_node_ANativeModifier$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_ANativeModifier$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ANativeModifier$sub_refs {
	struct _jc_soot_jimple_parser_node_TNative$object	*__5fnative__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_ANativeModifier$refs {
    _jc_soot_jimple_parser_node_ANativeModifier$sub_refs	soot_jimple_parser_node_ANativeModifier;
    _jc_soot_jimple_parser_node_PModifier$sub_refs	soot_jimple_parser_node_PModifier;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ANativeModifier$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_ANativeModifier$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PModifier$sub_nonrefs	soot_jimple_parser_node_PModifier;
    _jc_soot_jimple_parser_node_ANativeModifier$sub_nonrefs	soot_jimple_parser_node_ANativeModifier;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_ANativeModifier$object {
	_jc_soot_jimple_parser_node_ANativeModifier$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_ANativeModifier$vtype	*vtype;
	_jc_soot_jimple_parser_node_ANativeModifier$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_ANativeModifier$vtype _jc_soot_jimple_parser_node_ANativeModifier$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_ANativeModifier, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_ANativeModifier$class_object;

#endif	/* _JC_soot_jimple_parser_node_ANativeModifier_H_ */
